Function written in C++ estimating the gradient of the log likelihood
function for a given parameter set and given observations.
grad_ll(param_values, observations)Returns the gradient as a NumericVector.
NumericVector containing the probabilities of
a multinominal distribution. The length of this factor is the number of
categories - 1 since it contains only the parameters to be estimated.
NumericVector containing the number of
observations for each category of the multinominal distribution. The length
of this vector equals the number of categories.
Berding, Florian, and Pargmann, Julia (2022).Iota Reliability Concept of the Second Generation.Measures for Content Analysis Done by Humans or Artificial Intelligences. Berlin: Logos. https://doi.org/10.30819/5581