Learn R Programming

iotarelr (version 0.1.6)

iotarelr_new_rater: Sample Vector

Description

A vector containing the ratings of a new rater. The data is not real and is only created for illustration purposes.

Usage

iotarelr_new_rater

Arguments

Format

A vector with the length of 318.