Function for creating a plot object that can be plotted via 'ggplot2'.
Usage
plot_iota(
object,
xlab = "Amount on all cases",
ylab = "Categories",
liota = "Assignment of the true category (Iota)",
lcase2 = "Assignment to the false category",
lcase3 = "Assignment from the false true category",
lscale_quality = "Scale Quality",
lscale_cat = c("insufficent", "minimum", "satisfactory", "good", "excellent"),
number_size = 6,
key_size = 0.5,
text_size = 10,
legend_position = "bottom",
legend_direction = "vertical",
scale = "none"
)Arguments
- object
Estimates of Iota 2 created with
compute_iota2(),check_dgf()orcheck_new_rater().- xlab
Characterpassed to xlab() from scale_fill_manual(). Label of the x-axis.- ylab
Characterpassed to ylab() from scale_fill_manual(). Label of the y-axis.- liota
Characterpassed to labels() from scale_fill_manual(). Label for Iota.Amount of cases that are assigned to the correct category.- lcase2
Characterpassed to labels() from scale_fill_manual(). Label for the amount of cases that are assigned to a false category.- lcase3
Characterpassed to labels() from scale_fill_manual(). Label for the amount of cases that are assigned from a false category.- lscale_quality
characterpassed to scale_fill_manual() determining the title for the quality of a scale. Only used in conjunction withscale.- lscale_cat
Vector of strings with length 5. This vector contains the labels for each category of quality for the scale.
- number_size
Doublepassed to geom_text() determining the size of the numbers within the plot.- key_size
Doublepassed to theme() determining the size of the legend keys.- text_size
Doublepassed to theme() determining the size of the text within the legend.- legend_position
stringPosition of the legend. Possible values are "bottom","right","left", "top" and "none".- legend_direction
stringLayout of the items in the legend. Possible values are "horizontal" and "vertical".- scale
Stringfor requesting an additional plot of reliability on the scale level. Ifscale="dynamic_iota_index"Dynamic Iota Index is used. Ifscale="static_iota_index"Static Iota Index is used. Ifscale="none"no additional plot is created.