This function tests if the probabilities within the Assignment Error Matrix are in line with the assumption of weak superiority.
check_conformity_c(aem)Returns the number of violations of the assumption of weak superiority. 0 if the assumptions are fulfilled.
matrix of probabilities
Berding, Florian, and Pargmann, Julia (2022).Iota Reliability Concept of the Second Generation.Measures for Content Analysis Done by Humans or Artificial Intelligences. Berlin: Logos. https://doi.org/10.30819/5581